
# coding: utf-8

# # Classification: kNN
# 
# 
# We will use the machine learning framework sklearn (scikit-learn).
# 
# https://scikit-learn.org
# 

from my_plotting import my_plotDecisionFunction


# sklearn imports
from sklearn.datasets import make_moons
from sklearn.model_selection import train_test_split
from sklearn.neighbors import KNeighborsClassifier
from sklearn.metrics import confusion_matrix, accuracy_score
from sklearn.preprocessing import MinMaxScaler

# create data set
data, labels = make_moons(n_samples=500, noise=0.1, random_state=123)

# split into training and test set
train_data, test_data, train_labels, test_labels = train_test_split(
                            data, labels, test_size = 0.5, random_state=123)


# min-max scaling: determine scaling parameters
scaler = MinMaxScaler().fit(train_data)

# scale train set and test set
train_data = scaler.transform(train_data)
test_data = scaler.transform(test_data)

# create k-nearest neighbours with k = 3
model = KNeighborsClassifier(n_neighbors = 3)

# train model on training set
model.fit(train_data, train_labels)

# classification of test set
predictions = model.predict(test_data)

acc = accuracy_score(test_labels, predictions)
print("Overall accuracy: ", acc)

print("Confusion matrix")
cm = confusion_matrix(test_labels, predictions)
print(cm)




# plot decision function that was learned from training set
# this is an own function not contained in sklearn(!)
my_plotDecisionFunction(train_data, train_labels, model, 
                        title = "k-NN", filename="classification_k-nn_moons_sklearn")
