# -*- coding: utf-8 -*-
"""
Created on Thu May 19 17:11:04 2022

@author: anth
"""

import matplotlib.pyplot as plt
from sklearn.datasets import make_blobs
from sklearn.preprocessing import MinMaxScaler
from sklearn.cluster import KMeans


# create data set with four clusters
data, _ = make_blobs(n_samples=200, n_features=2, 
                     centers=[(1,1), (1,8), (8,1), (8,8)], 
                     cluster_std = [1, 0.5, 1, 2], 
                     random_state=123)

# plot the input data
plt.scatter(data[:, 0], data[:, 1], edgecolors='black')
plt.savefig('clustering_raw_data.png', transparent=True)
plt.show()

# min-max scaling
scaler = MinMaxScaler().fit(data)
data = scaler.transform(data)

#cluster the data with the specified number of clusters
clust = KMeans(n_clusters=4)
clust.fit(data)

#mysymbols = ['o','s','v','^']
# plot cluster results with centers 
plt.figure(figsize=(6, 6))
plt.scatter(data[:, 0], data[:, 1], c = clust.labels_, 
            cmap=plt.cm.coolwarm, edgecolors='black')
plt.scatter(clust.cluster_centers_[:, 0], 
            clust.cluster_centers_[:, 1],
            marker='X', s=100, c="black")
plt.title('k-means')
plt.savefig('clustering_k-means_prog.png')
plt.show()




#moons


import matplotlib.pyplot as plt
from sklearn.datasets import make_moons
from sklearn.preprocessing import MinMaxScaler
from sklearn.cluster import KMeans

data, _ = make_moons(n_samples=500, noise=0.1, random_state=123)

# plot the input data
plt.scatter(data[:, 0], data[:, 1], edgecolors='black')
plt.savefig('clustering_raw_data_moons.png', transparent=True)
plt.show()

scaler = MinMaxScaler().fit(data)
data = scaler.transform(data)

clust = KMeans(n_clusters=2)
clust.fit(data)

# plot cluster results with centers 
plt.figure(figsize=(6, 6))
plt.scatter(data[:, 0], data[:, 1], c = clust.labels_, 
            cmap=plt.cm.coolwarm, edgecolors='black')
plt.scatter(clust.cluster_centers_[:, 0], 
            clust.cluster_centers_[:, 1],
            marker='X', s=100, c="black")
plt.title('k-means')
plt.savefig('clustering_k-means_prog_moons.png')
plt.show()
