# functions to plot a decision function in 2D plot

# No need to understand this source code!!!
# just for educational reasons...

import numpy as np
import matplotlib.pyplot as plt


def calcMinMaxVal(dataIn, border = 0.2):
    minVal = min(dataIn) - border * (max(dataIn) - min(dataIn))
    maxVal = max(dataIn) + border * (max(dataIn) - min(dataIn))
    return minVal, maxVal


def createMeshgrid(dataIn):
    # calculate value range for artificial data points
    minX, maxX = calcMinMaxVal(dataIn[:,0])
    minY, maxY = calcMinMaxVal(dataIn[:,1])

    # create artificial data points
    xx, yy = np.meshgrid(np.linspace(minX, maxX, 500), np.linspace(minY, maxY, 500))
    return xx,yy


def my_plotDecisionFunction(dataIn, labelsIn, model, title, plotDevice = plt, standAlonePlot = True, filename=None):

    # create data to be able to plot the decision function
    xx, yy = createMeshgrid(dataIn)
  
    # classify artificial data with the model
    pred = model.predict(np.c_[xx.ravel(), yy.ravel()])
    pred = pred.reshape(xx.shape)

    # plot training set (first 2 dimensions)
    plotDevice.contourf(xx, yy, pred, cmap=plt.cm.Paired, alpha=0.5)
    plotDevice.scatter(dataIn[:, 0], dataIn[:, 1], c=labelsIn, cmap=plt.cm.coolwarm)
    plotDevice.title(title)
    plotDevice.xlabel("x1")
    plotDevice.ylabel("x2")
    
    
    if(standAlonePlot):
        if(filename != None):
            plotDevice.savefig(filename + '.png', bbox_inches='tight', dpi=300)
        plotDevice.show()

    return

    
def my_plotSVM(dataIn, model):
    # mark support vectors black
    plt.scatter(model.support_vectors_[:, 0], model.support_vectors_[:, 1], c="black")

    # get the separating hyperplane
    w = model.coef_[0]
    a = -w[0] / w[1]    # Koeff. für Geradengleichung

    xmin, xmax = calcMinMaxVal(dataIn[:,0])
    xx = np.linspace(xmin, xmax)
    yy = a * xx - (model.intercept_[0]) / w[1]  #Geradengleichung

    # supporting hyperplanes: durch support vectors
    b = model.support_vectors_[0]    # erster SV
    yy_down = a * xx + (b[1] - a * b[0])
    b = model.support_vectors_[-1]    # letzter SV
    yy_up = a * xx + (b[1] - a * b[0])

    # plot hyperplane und supporting hyperplane
    plt.plot(xx, yy, 'k-')    # hyperplane
    plt.plot(xx, yy_down, 'k--') # supporting hyperplane
    plt.plot(xx, yy_up, 'k--') #supporting hyperplane

    plt.show()
    return
    
    